@@ -28,8 +28,8 @@ if(!exists("Sys.setenv", envir = baseenv())) Sys.setenv <- Sys.putenv
   SYS <- ""
   if (.Platform$OS.type == "windows") {
     if (Sys.getenv("OSTYPE") == "msys") SYS <- "msys"
-    else if (nchar(Sys.getenv("OSTYPE")) == 0) SYS <- "WinNat"
     else if (Sys.getenv("OSTYPE") == "cygwin") SYS <- "cygwin"
+    else SYS <- "WinNat"
   } else if (.Platform$OS.type == "unix") SYS <- "unix"
   assign("SYS", SYS, envir=.GRASS_CACHE)
   res <- ""
